module.exports = {
  dependencies: [ 'glob' ],
  onInitCompilation: function(api) {
    // This will ensure the unsupported allowTs attribute is ignored
    api.tsconfig.ignore('compilerOptions.allowTs');
  },
  onPostCompilation: function(api) {
    const path = require('path');
    const fs = require('fs');
    const glob = require('glob');

    // Add included files from config
    const includedFiles = new Set();
    for (const includedFromConfig of api.tsconfig.include) {
      const files = glob.sync(includedFromConfig, { cwd: api.tsconfig.directory });
      for (const file of files) {
        includedFiles.add(file);
      }
    }

    // Remove excluded files from config
    for (const excludedFromConfig of api.tsconfig.exclude) {
      const files = glob.sync(excludedFromConfig, { cwd: api.tsconfig.directory });
      for (const file of files) {
        includedFiles.delete(file);
      }
    }

    console.log(Array.from(includedFiles));
  }
}